@@ -20,6 +20,15 @@ class apexlWPManageService
         return self::makePostRequest('user/getdata', (object)[
             'email' =>  $email
         ]);
+    }
+
+    public static function resetWPUserPassword($email, $password, $remoteUserId)
+    {
+        return self::makePostRequest('user/resetpassword', (object)[
+            'email' =>  $email,
+            'password' => $password,
+            'ID' => $remoteUserId
+        ]);
 
     }
 
